{
  config,
  ...
}:
let
  sources = import ./lon.nix;
  pkgs = import sources.nixpkgs { };
in
{
  imports = [
    ./hardware-configuration.nix
    ./kahulm.nix
  ];

  boot.loader = {
    systemd-boot.enable = true;
    efi.canTouchEfiVariables = true;
  };

  nixpkgs.pkgs = pkgs;
  nix = {
    nixPath = [
      "nixpkgs=${sources.nixpkgs}"
      "nixos=${sources.nixpkgs}"
      "nixos-config=/etc/nixos/configuration.nix"
    ];
    channel.enable = false;
    settings.nix-path = config.nix.nixPath;
    package = pkgs.lix;
  };
  documentation.nixos.enable = false; # they managed to make this fail the build...

  networking = {
    hostName = "kahulm";
    useNetworkd = true;
    nftables.enable = true;
  };
  systemd.network = {
    enable = true;
    networks."10-ens18" = {
      name = "ens18";
      address = [ "129.199.146.62/24" ];
      routes = [
        { Gateway = "129.199.146.254"; }
      ];
      dns = [
        "129.199.96.11"
        "129.199.162.16"
        "129.199.98.16"
      ];
    };
  };

  time.timeZone = "Europe/Paris";
  i18n.defaultLocale = "en_US.UTF-8";
  console = {
    font = "Lat2-Terminus16";
    keyMap = "fr";
  };

  users.users.root.openssh.authorizedKeys.keys = [
    ##### DGNum #####

    # catvayor
    "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIFfIJ8BToZ9EDxBsEJXQhUju7gm+rUDjGCNMvFSZCl1o openpgp:0x5CADCA1B"
    "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAICdOxx4I8BSbYPdouvuzDepwTwzQzGSBCNIV8TB5dduT openpgp:0xF6018131"
    # mdebray
    "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIEpwF+XD3HgX64kqD42pcEZRNYAWoO4YNiOm5KO4tH6o maurice@polaris"
    "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIFdDnSl3cyWil+S5JiyGqOvBR3wVh+lduw58S5WvraoL maurice@fekda"
    # thubrecht
    "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIL+EZXYziiaynJX99EW8KesnmRTZMof3BoIs3mdEl8L3"
    "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIHL4M4HKjs4cjRAYRk9pmmI8U0R4+T/jQh6Fxp/i1Eoy"
    "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIPM1jpXR7BWQa7Sed7ii3SbvIPRRlKb3G91qC0vOwfJn"

    ##### DGNum end #####

    # Hubert
    "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIHRPO1Ynb1SUDlVpadqG5Lo9sWs7jlHolWTzHUq8x98a"
    # Matthieu
    "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIAhwbuqaUSxuvaxYRaxM5jbMRHaB3JGdzuy1bMGX3YVk"
  ];

  environment = {
    variables.EDITOR = "nvim";
    systemPackages = with pkgs; [
      wget
      btop
      dig
      git
      htop
      tcpdump
      lon
    ];
  };

  programs = {
    neovim = {
      enable = true;
      vimAlias = true;
    };
    mosh.enable = true;
  };

  services.openssh = {
    enable = true;
    settings = {
      KbdInteractiveAuthentication = false;
      LoginGraceTime = "30";
      MaxSessions = "64";
      MaxStartups = "64";
      PasswordAuthentication = false;
    };
  };

  system.stateVersion = "25.05";
}
