let
  host = "kahulm.dgnum.eu";
  port = 3009;
in
{
  imports = [ ../module.nix ];

  security.acme = {
    acceptTerms = true;
    defaults.email = "acme@dgnum.eu";
  };

  services = {
    kahulm = {
      inherit port;
      enable = true;
      baseUrl = "https://${host}";
      sessionSecretFile = "/etc/secrets/kahulm-session-secret";
    };

    nginx = {
      enable = true;
      recommendedBrotliSettings = true;
      recommendedGzipSettings = true;
      recommendedOptimisation = true;
      recommendedProxySettings = true;
      recommendedTlsSettings = true;
      recommendedZstdSettings = true;

      virtualHosts.${host} = {
        enableACME = true;
        forceSSL = true;
        locations."/" = {
          proxyPass = "http://127.0.0.1:${toString port}";
        };
      };
    };
  };

  networking.firewall.allowedTCPPorts = [
    80
    443
  ];
}
