{ lib
, stdenv
, fetchYarnDeps
, yarn
, nodejs
, python3
, prefetch-yarn-deps
, fixup-yarn-lock
, nodePackages
}:

stdenv.mkDerivation rec {
  pname = "kahulm";
  version = "unstable";

  src =
    with lib.fileset;
    toSource {
      root = ./..;
      fileset = intersection (gitTracked ./..) (
        fileFilter (file: !file.hasExt "nix") ./..
      );
    };

  offlineCache = fetchYarnDeps {
    yarnLock = "${src}/yarn.lock";
    hash = "sha256-NH3uckI1M+/WKs7XPWoFYhVv1eOl7II1PrRYf7LbutM=";
  };

  nativeBuildInputs = [
    yarn
    nodejs
    prefetch-yarn-deps
    fixup-yarn-lock
    python3
    nodePackages.node-gyp-build
    nodePackages.node-pre-gyp
  ];

  configurePhase = ''
    runHook preConfigure

    export HOME=$(mktemp -d)
    yarn config --offline set yarn-offline-mirror ${offlineCache}
    fixup-yarn-lock yarn.lock

    mkdir -p "$HOME/.node-gyp/${nodejs.version}"
    echo 9 >"$HOME/.node-gyp/${nodejs.version}/installVersion"
    ln -sfv "${nodejs}/include" "$HOME/.node-gyp/${nodejs.version}"
    export npm_config_nodedir=${nodejs}

    yarn --offline --frozen-lockfile --ignore-platform --ignore-engines --no-progress --non-interactive install
    patchShebangs node_modules

    runHook postConfigure
  '';

  buildPhase = ''
    runHook preBuild

    yarn --offline run build

    runHook postBuild
  '';

  installPhase = ''
    runHook preInstall

    mkdir $out

    cp -r public/ $out
    cp -r dist/ $out
    cp -r views/ $out
    cp -r node_modules/ $out
    cp -r kahulm.sqlite $out

    runHook postInstall
  '';

  meta = {
    description = "Kahulm";
    license = lib.licenses.mit;
    maintainers = with lib.maintainers; [ soyouzpanda ];
  };
}
