import { Request, Response } from "express";
import { findBestPlayers, findBestTeams, Team, User, listPlayers } from "../db";
import { pagination } from "../utils/pagination";

export async function showPlayersHighscore(req: Request, res: Response) {
  const playersPerPage = 5;
  const playerCount = await User.count();
  const maxPageCount = Math.ceil(playerCount / playersPerPage);

  const page = Math.min(maxPageCount, Math.max(1, Number.parseInt((req.query.p || "1") as string)));
  const users = await findBestPlayers((page - 1) * playersPerPage, playersPerPage);
  const scores = users.map(user => {
    const frontendScore = {
      name: user.id,
      score: user.score
    };
    return frontendScore;
  });

  res.render('highscore', { scores: scores, pagination: pagination(page, playerCount, { recordsPerPage: playersPerPage }) });
}


export async function showTeamsHighscore(req: Request, res: Response) {
  const teamsPerPage = 5;
  const teamCount = await Team.count();
  const maxPageCount = Math.ceil(teamCount / teamsPerPage);

  const page = Math.min(maxPageCount, Math.max(1, Number.parseInt((req.query.p || "1") as string)));
  const teams = await findBestTeams((page - 1) * teamsPerPage, teamsPerPage);
  const scores = teams.map(team => {
    const frontendScore = {
      name: team.id,
      score: team.score
    };
    return frontendScore;
  });

  res.render('highscore', { scores: scores, pagination: pagination(page, teamCount, { recordsPerPage: teamsPerPage }) });
}
