import express, { Express, NextFunction, Request, Response } from "express";
import dotenv from "dotenv";
import morgan from "morgan";
import helmet from "helmet";
import compression from "compression";
import cookieSession from "cookie-session";
import path from "path";

import router from "./routes/main";
import { initDatabase } from "./db";
import { loadQuestionTable } from "./loadQuestionTable";
import { loadUserTable } from "./loadUserTable";
import { existsSync } from "fs";

dotenv.config();

const app: Express = express();
const port = process.env.PORT || 3000;

if (!existsSync(process.env.DB_FILE || "kahulm.sqlite")) {
  (async () => {
    await initDatabase();
    // await loadQuestionTable('questions.csv');
    // await loadUserTable('users.csv');
  })();
}

app.use(morgan("dev"));
app.use(helmet());
app.use(compression());
app.use("/static", express.static(path.join(__dirname, "../public")));
app.set("view engine", "pug");

app.use(
  cookieSession({
    name: "session",
    keys: [process.env.SESSION_SECRET || "TEST"],
    maxAge: 1209600000, // 14 days
  }),
);

app.use(router);

app.listen(port, () => {
  console.log(
    `[server]: Server is running at ${process.env.BASE_URL || `http://localhost:${port}`}`,
  );
});
