import fs from 'node:fs';
import { open } from 'node:fs/promises';
import { parse } from 'csv-parse';
import { addUser, Team } from './db';

function removeAccents(str: string): string {
  return str.normalize("NFD").replace(/\p{Diacritic}/gu, "");
}

let possiblePasswords: Array<string> = [];
const generatePassword = () => {
  const idx = Math.floor(Math.random() * possiblePasswords.length);
  const pickedPassword = possiblePasswords[idx];
  possiblePasswords.splice(idx, 1);
  return pickedPassword;
}

const generateLogin = (login: string): string => {
  return removeAccents(login).normalize().toLowerCase().trim().replace(' ', '');
}

const getTeam = async (name: string): Promise<Team> => {
  return (await Team.findOrCreate({ where: { id: name }, defaults: { id: name } }))[0];
}

let passwords: Array<Array<string>> = [];
const handleRecord = async (record: any) => {
  const teamName = (record[2] as string).trim();
  const teamDb = await getTeam(teamName);
  const login = generateLogin(record[3]);
  const isAdmin = teamName == 'Légendaire';
  const password = generatePassword();

  passwords.push([login, password]);
  const userDb = await addUser(login, password, isAdmin);
  userDb.setTeam(teamDb);
}

export const loadUserTable = async (file: string) => {
  console.log("Loading users");

  const pokemonsFile = await open('./pokemons.txt');
  for await (const line of pokemonsFile.readLines()) {
    possiblePasswords.push(removeAccents(line.trim().toLowerCase()));
  }
  await pokemonsFile.close();

  const parser = fs
    .createReadStream(file)
    .pipe(parse({ fromLine: 2 }));

  for await (const record of parser) {
    await handleRecord(record);
  }

  let passwordFile = await open('./passwords.csv', "w");
  for (const [login, password] of passwords) {
    passwordFile.write(`${login},${password}\n`);
  }

  console.log("Users loaded");
};
