
import { NextFunction, Request, Response } from "express";
import PromiseRouter from "express-promise-router";
import { ensureAdmin, ensureAuthenticated } from "../middlewares/auth";

import LoginRoute from './login';
import AdminRoute from './admin';
import LocationRoute from './location';
import QuestionRoute from './question';
import ScoresRoute from './scores';

const router = PromiseRouter();

router.use((req: Request, res: Response, next: NextFunction) => {
  // Let all requests and views have access to the current session data.
  res.locals.session = req.session;
  next();
});

router.get("/", async (req: Request, res: Response) => {
  res.render('index', { title: 'Hey' });
});

router.use("/admin", ensureAdmin, AdminRoute);
router.use(LoginRoute);
router.use('/l', ensureAuthenticated, LocationRoute);
router.use('/q', ensureAuthenticated, QuestionRoute);
router.use("/s", ScoresRoute);

export default router;
